what.examples API documentation

# what.examples

This module implements several examples, including model inference and adversarial attacks.

Use `what example run` to run examples.

               Demo                Type             Description
    --------------------------------------------------------------------------------
    1 :     Yolov3 Demo      Model Inference        Yolov3 Object Detection.
    2 :     Yolov4 Demo      Model Inference        Yolov4 Object Detection.
    3 :   FasterRCNN Demo    Model Inference        FRCNN Object Detection.
    4 : MobileNet SSD Demo   Model Inference        MobileNet SSD Object Detection.
    5 :  TOG Attack Demo    Adversarial Attack      Real-time TOG Attack against Yolov3 Tiny.
    6 :  PCB Attack Demo    Adversarial Attack      Real-time PCB Attack against Yolov3 Tiny.

    Please input the example index:

# Model Inference:

Object Detection Demos.

## what.examples.yolov3_demo

## what.examples.yolov4_demo

## what.examples.faster_rcnn_demo

## what.examples.mobilenet_ssd_demo

# Adversarial Attacks:

Real-time Adversarial Attacks against Object Detection.

## what.examples.yolov3_tog_attack_demo

## what.examples.yolov3_pcb_attack_demo

View Source

     1r'''
     2This module implements several examples, including model inference and adversarial attacks.
     3
     4Use `what example run` to run examples.
     5
     6```
     7           Demo                Type             Description
     8--------------------------------------------------------------------------------
     91 :     Yolov3 Demo      Model Inference        Yolov3 Object Detection.
    102 :     Yolov4 Demo      Model Inference        Yolov4 Object Detection.
    113 :   FasterRCNN Demo    Model Inference        FRCNN Object Detection.
    124 : MobileNet SSD Demo   Model Inference        MobileNet SSD Object Detection.
    135 :  TOG Attack Demo    Adversarial Attack      Real-time TOG Attack against Yolov3 Tiny.
    146 :  PCB Attack Demo    Adversarial Attack      Real-time PCB Attack against Yolov3 Tiny.
    15
    16Please input the example index:
    17```
    18
    19<br />
    20
    21# Model Inference:
    22
    23Object Detection Demos.
    24
    25## what.examples.yolov3_demo
    26## what.examples.yolov4_demo
    27
    28## what.examples.faster_rcnn_demo
    29## what.examples.mobilenet_ssd_demo
    30
    31<br />
    32
    33# Adversarial Attacks:
    34
    35Real-time Adversarial Attacks against Object Detection.
    36
    37## what.examples.yolov3_tog_attack_demo
    38## what.examples.yolov3_pcb_attack_demo
    39
    40'''
    41
    42from what.examples.yolov3_demo import yolov3_inference_demo
    43from what.examples.yolov4_demo import yolov4_inference_demo
    44from what.examples.faster_rcnn_demo import frcnn_inference_demo
    45from what.examples.mobilenet_ssd_demo import mobilenet_ssd_inference_demo
    46
    47from what.examples.yolov3_tog_attack_demo import yolov3_tog_attack_demo
    48from what.examples.yolov3_pcb_attack_demo import yolov3_pcb_attack_demo